/**
 * Copyright (c) Facebook, Inc. and its affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */
import React from "react";
import {useThemeConfig} from "@docusaurus/theme-common";
import FooterLinks from "@theme/Footer/Links";
import FooterLogo from "@theme/Footer/Logo";
import FooterCopyright from "@theme/Footer/Copyright";
import FooterLayout from "@theme/Footer/Layout";
import { FaYoutube, FaLinkedin, FaGitlab, FaTwitter } from "react-icons/fa";
import Froggitblanc from "/static/img/logo_froggit_blanc.png";


function Footer() {
  const {footer} = useThemeConfig();

  if (!footer) {
    return null;
  }

  const {copyright, icons, links, logo, style, FooterIcons} = footer;
  return (
    <>
      <div className="footer">

        <div className="footer_container">

          <a href="https://lab.frogg.it/froggit" target="_blank" rel="noreferrer">
            <img className="footer_icons" src={Froggitblanc} alt="Logo Froggit blanc" />
          </a>

          <a href="https://gitlab.com/froggit" target="_blank" rel="noreferrer">
            <FaGitlab className="footer_icons" />
          </a>

          <a href="https://www.youtube.com/channel/UCauIDghddUNu6Fto1nR9Bmg/?sub_confirmation=1" target="_blank" rel="noreferrer">
            <FaYoutube className="footer_icons" />
          </a>

          <a href="https://www.linkedin.com/company/froggit" target="_blank" rel="noreferrer">
            <FaLinkedin className="footer_icons" />
          </a>
          
          <a href="https://twitter.com/art_devops" target="_blank" rel="noreferrer">
            <FaTwitter className="footer_icons" />
          </a>
      
        </div>

        <div>
          
          <FooterLayout
            icons={icons && <FooterIcons icons={icons} />}
            style={style}
            links={links && links.length > 0 && <FooterLinks links={links} />}
            logo={logo && <FooterLogo logo={logo} />}
            copyright={copyright && <FooterCopyright copyright={copyright} />}
          />
        </div>
      </div>
    </>
  );
}

export default React.memo(Footer);
